# flexprice-client
FlexPrice API Service

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/flexprice/python-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/flexprice/python-sdk.git`)

Then import the package:
```python
import flexprice_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import flexprice_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import flexprice_client
from flexprice_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to /v1
# See configuration.py for a list of all supported configuration parameters.
configuration = flexprice_client.Configuration(
    host = "/v1"
)



# Enter a context with an instance of the API client
with flexprice_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = flexprice_client.AuthApi(api_client)
    login = flexprice_client.DtoLoginRequest() # DtoLoginRequest | Login request

    try:
        # Login
        api_response = api_instance.auth_login_post(login)
        print("The response of AuthApi->auth_login_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthApi->auth_login_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to */v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**auth_login_post**](docs/AuthApi.md#auth_login_post) | **POST** /auth/login | Login
*AuthApi* | [**auth_signup_post**](docs/AuthApi.md#auth_signup_post) | **POST** /auth/signup | Sign up
*CustomersApi* | [**customers_get**](docs/CustomersApi.md#customers_get) | **GET** /customers | Get customers
*CustomersApi* | [**customers_id_delete**](docs/CustomersApi.md#customers_id_delete) | **DELETE** /customers/{id} | Delete a customer
*CustomersApi* | [**customers_id_entitlements_get**](docs/CustomersApi.md#customers_id_entitlements_get) | **GET** /customers/{id}/entitlements | Get customer entitlements
*CustomersApi* | [**customers_id_get**](docs/CustomersApi.md#customers_id_get) | **GET** /customers/{id} | Get a customer
*CustomersApi* | [**customers_id_put**](docs/CustomersApi.md#customers_id_put) | **PUT** /customers/{id} | Update a customer
*CustomersApi* | [**customers_id_usage_get**](docs/CustomersApi.md#customers_id_usage_get) | **GET** /customers/{id}/usage | Get customer usage summary
*CustomersApi* | [**customers_lookup_lookup_key_get**](docs/CustomersApi.md#customers_lookup_lookup_key_get) | **GET** /customers/lookup/{lookup_key} | Get a customer by lookup key
*CustomersApi* | [**customers_post**](docs/CustomersApi.md#customers_post) | **POST** /customers | Create a customer
*EntitlementsApi* | [**entitlements_get**](docs/EntitlementsApi.md#entitlements_get) | **GET** /entitlements | Get entitlements
*EntitlementsApi* | [**entitlements_id_delete**](docs/EntitlementsApi.md#entitlements_id_delete) | **DELETE** /entitlements/{id} | Delete an entitlement
*EntitlementsApi* | [**entitlements_id_get**](docs/EntitlementsApi.md#entitlements_id_get) | **GET** /entitlements/{id} | Get an entitlement by ID
*EntitlementsApi* | [**entitlements_id_put**](docs/EntitlementsApi.md#entitlements_id_put) | **PUT** /entitlements/{id} | Update an entitlement
*EntitlementsApi* | [**entitlements_post**](docs/EntitlementsApi.md#entitlements_post) | **POST** /entitlements | Create a new entitlement
*EntitlementsApi* | [**plans_id_entitlements_get**](docs/EntitlementsApi.md#plans_id_entitlements_get) | **GET** /plans/{id}/entitlements | Get plan entitlements
*EnvironmentsApi* | [**environments_get**](docs/EnvironmentsApi.md#environments_get) | **GET** /environments | Get environments
*EnvironmentsApi* | [**environments_id_get**](docs/EnvironmentsApi.md#environments_id_get) | **GET** /environments/{id} | Get an environment
*EnvironmentsApi* | [**environments_id_put**](docs/EnvironmentsApi.md#environments_id_put) | **PUT** /environments/{id} | Update an environment
*EnvironmentsApi* | [**environments_post**](docs/EnvironmentsApi.md#environments_post) | **POST** /environments | Create an environment
*EventsApi* | [**events_bulk_post**](docs/EventsApi.md#events_bulk_post) | **POST** /events/bulk | Bulk Ingest events
*EventsApi* | [**events_get**](docs/EventsApi.md#events_get) | **GET** /events | Get raw events
*EventsApi* | [**events_post**](docs/EventsApi.md#events_post) | **POST** /events | Ingest event
*EventsApi* | [**events_usage_meter_post**](docs/EventsApi.md#events_usage_meter_post) | **POST** /events/usage/meter | Get usage by meter
*EventsApi* | [**events_usage_post**](docs/EventsApi.md#events_usage_post) | **POST** /events/usage | Get usage statistics
*FeaturesApi* | [**features_get**](docs/FeaturesApi.md#features_get) | **GET** /features | List features
*FeaturesApi* | [**features_id_delete**](docs/FeaturesApi.md#features_id_delete) | **DELETE** /features/{id} | Delete a feature
*FeaturesApi* | [**features_id_get**](docs/FeaturesApi.md#features_id_get) | **GET** /features/{id} | Get a feature by ID
*FeaturesApi* | [**features_id_put**](docs/FeaturesApi.md#features_id_put) | **PUT** /features/{id} | Update a feature
*FeaturesApi* | [**features_post**](docs/FeaturesApi.md#features_post) | **POST** /features | Create a new feature
*IntegrationsApi* | [**secrets_integrations_id_delete**](docs/IntegrationsApi.md#secrets_integrations_id_delete) | **DELETE** /secrets/integrations/{id} | Delete an integration
*IntegrationsApi* | [**secrets_integrations_linked_get**](docs/IntegrationsApi.md#secrets_integrations_linked_get) | **GET** /secrets/integrations/linked | List linked integrations
*IntegrationsApi* | [**secrets_integrations_provider_get**](docs/IntegrationsApi.md#secrets_integrations_provider_get) | **GET** /secrets/integrations/{provider} | Get integration details
*IntegrationsApi* | [**secrets_integrations_provider_post**](docs/IntegrationsApi.md#secrets_integrations_provider_post) | **POST** /secrets/integrations/{provider} | Create or update an integration
*InvoicesApi* | [**customers_id_invoices_summary_get**](docs/InvoicesApi.md#customers_id_invoices_summary_get) | **GET** /customers/{id}/invoices/summary | Get a customer invoice summary
*InvoicesApi* | [**invoices_get**](docs/InvoicesApi.md#invoices_get) | **GET** /invoices | List invoices
*InvoicesApi* | [**invoices_id_finalize_post**](docs/InvoicesApi.md#invoices_id_finalize_post) | **POST** /invoices/{id}/finalize | Finalize an invoice
*InvoicesApi* | [**invoices_id_get**](docs/InvoicesApi.md#invoices_id_get) | **GET** /invoices/{id} | Get an invoice by ID
*InvoicesApi* | [**invoices_id_payment_attempt_post**](docs/InvoicesApi.md#invoices_id_payment_attempt_post) | **POST** /invoices/{id}/payment/attempt | Attempt payment for an invoice
*InvoicesApi* | [**invoices_id_payment_put**](docs/InvoicesApi.md#invoices_id_payment_put) | **PUT** /invoices/{id}/payment | Update invoice payment status
*InvoicesApi* | [**invoices_id_pdf_get**](docs/InvoicesApi.md#invoices_id_pdf_get) | **GET** /invoices/{id}/pdf | Get PDF for an invoice
*InvoicesApi* | [**invoices_id_void_post**](docs/InvoicesApi.md#invoices_id_void_post) | **POST** /invoices/{id}/void | Void an invoice
*InvoicesApi* | [**invoices_post**](docs/InvoicesApi.md#invoices_post) | **POST** /invoices | Create a new invoice
*InvoicesApi* | [**invoices_preview_post**](docs/InvoicesApi.md#invoices_preview_post) | **POST** /invoices/preview | Get a preview invoice
*MetersApi* | [**meters_get**](docs/MetersApi.md#meters_get) | **GET** /meters | List meters
*MetersApi* | [**meters_id_delete**](docs/MetersApi.md#meters_id_delete) | **DELETE** /meters/{id} | Delete meter
*MetersApi* | [**meters_id_disable_post**](docs/MetersApi.md#meters_id_disable_post) | **POST** /meters/{id}/disable | Disable meter [TODO: Deprecate]
*MetersApi* | [**meters_id_get**](docs/MetersApi.md#meters_id_get) | **GET** /meters/{id} | Get meter
*MetersApi* | [**meters_id_put**](docs/MetersApi.md#meters_id_put) | **PUT** /meters/{id} | Update meter
*MetersApi* | [**meters_post**](docs/MetersApi.md#meters_post) | **POST** /meters | Create meter
*PaymentsApi* | [**payments_get**](docs/PaymentsApi.md#payments_get) | **GET** /payments | List payments
*PaymentsApi* | [**payments_id_delete**](docs/PaymentsApi.md#payments_id_delete) | **DELETE** /payments/{id} | Delete a payment
*PaymentsApi* | [**payments_id_get**](docs/PaymentsApi.md#payments_id_get) | **GET** /payments/{id} | Get a payment by ID
*PaymentsApi* | [**payments_id_process_post**](docs/PaymentsApi.md#payments_id_process_post) | **POST** /payments/{id}/process | Process a payment
*PaymentsApi* | [**payments_id_put**](docs/PaymentsApi.md#payments_id_put) | **PUT** /payments/{id} | Update a payment
*PaymentsApi* | [**payments_post**](docs/PaymentsApi.md#payments_post) | **POST** /payments | Create a new payment
*PlansApi* | [**plans_get**](docs/PlansApi.md#plans_get) | **GET** /plans | Get plans
*PlansApi* | [**plans_id_delete**](docs/PlansApi.md#plans_id_delete) | **DELETE** /plans/{id} | Delete a plan
*PlansApi* | [**plans_id_get**](docs/PlansApi.md#plans_id_get) | **GET** /plans/{id} | Get a plan
*PlansApi* | [**plans_id_put**](docs/PlansApi.md#plans_id_put) | **PUT** /plans/{id} | Update a plan
*PlansApi* | [**plans_post**](docs/PlansApi.md#plans_post) | **POST** /plans | Create a new plan
*PricesApi* | [**prices_get**](docs/PricesApi.md#prices_get) | **GET** /prices | Get prices
*PricesApi* | [**prices_id_delete**](docs/PricesApi.md#prices_id_delete) | **DELETE** /prices/{id} | Delete a price
*PricesApi* | [**prices_id_get**](docs/PricesApi.md#prices_id_get) | **GET** /prices/{id} | Get a price by ID
*PricesApi* | [**prices_id_put**](docs/PricesApi.md#prices_id_put) | **PUT** /prices/{id} | Update a price
*PricesApi* | [**prices_post**](docs/PricesApi.md#prices_post) | **POST** /prices | Create a new price
*SubscriptionsApi* | [**subscriptions_get**](docs/SubscriptionsApi.md#subscriptions_get) | **GET** /subscriptions | List subscriptions
*SubscriptionsApi* | [**subscriptions_id_cancel_post**](docs/SubscriptionsApi.md#subscriptions_id_cancel_post) | **POST** /subscriptions/{id}/cancel | Cancel subscription
*SubscriptionsApi* | [**subscriptions_id_get**](docs/SubscriptionsApi.md#subscriptions_id_get) | **GET** /subscriptions/{id} | Get subscription
*SubscriptionsApi* | [**subscriptions_id_pause_post**](docs/SubscriptionsApi.md#subscriptions_id_pause_post) | **POST** /subscriptions/{id}/pause | Pause a subscription
*SubscriptionsApi* | [**subscriptions_id_pauses_get**](docs/SubscriptionsApi.md#subscriptions_id_pauses_get) | **GET** /subscriptions/{id}/pauses | List all pauses for a subscription
*SubscriptionsApi* | [**subscriptions_id_resume_post**](docs/SubscriptionsApi.md#subscriptions_id_resume_post) | **POST** /subscriptions/{id}/resume | Resume a paused subscription
*SubscriptionsApi* | [**subscriptions_post**](docs/SubscriptionsApi.md#subscriptions_post) | **POST** /subscriptions | Create subscription
*SubscriptionsApi* | [**subscriptions_usage_post**](docs/SubscriptionsApi.md#subscriptions_usage_post) | **POST** /subscriptions/usage | Get usage by subscription
*TasksApi* | [**tasks_get**](docs/TasksApi.md#tasks_get) | **GET** /tasks | List tasks
*TasksApi* | [**tasks_id_get**](docs/TasksApi.md#tasks_id_get) | **GET** /tasks/{id} | Get a task by ID
*TasksApi* | [**tasks_id_process_post**](docs/TasksApi.md#tasks_id_process_post) | **POST** /tasks/{id}/process | Process a task
*TasksApi* | [**tasks_id_status_put**](docs/TasksApi.md#tasks_id_status_put) | **PUT** /tasks/{id}/status | Update task status
*TasksApi* | [**tasks_post**](docs/TasksApi.md#tasks_post) | **POST** /tasks | Create a new task
*TenantsApi* | [**tenant_billing_get**](docs/TenantsApi.md#tenant_billing_get) | **GET** /tenant/billing | Get billing usage for the current tenant
*TenantsApi* | [**tenants_id_get**](docs/TenantsApi.md#tenants_id_get) | **GET** /tenants/{id} | Get tenant by ID
*TenantsApi* | [**tenants_post**](docs/TenantsApi.md#tenants_post) | **POST** /tenants | Create a new tenant
*TenantsApi* | [**tenants_update_put**](docs/TenantsApi.md#tenants_update_put) | **PUT** /tenants/update | Update a tenant
*UsersApi* | [**users_me_get**](docs/UsersApi.md#users_me_get) | **GET** /users/me | Get user info
*WalletsApi* | [**customers_id_wallets_get**](docs/WalletsApi.md#customers_id_wallets_get) | **GET** /customers/{id}/wallets | Get wallets by customer ID
*WalletsApi* | [**wallets_id_balance_real_time_get**](docs/WalletsApi.md#wallets_id_balance_real_time_get) | **GET** /wallets/{id}/balance/real-time | Get wallet balance
*WalletsApi* | [**wallets_id_get**](docs/WalletsApi.md#wallets_id_get) | **GET** /wallets/{id} | Get wallet by ID
*WalletsApi* | [**wallets_id_put**](docs/WalletsApi.md#wallets_id_put) | **PUT** /wallets/{id} | Update a wallet
*WalletsApi* | [**wallets_id_terminate_post**](docs/WalletsApi.md#wallets_id_terminate_post) | **POST** /wallets/{id}/terminate | Terminate a wallet
*WalletsApi* | [**wallets_id_top_up_post**](docs/WalletsApi.md#wallets_id_top_up_post) | **POST** /wallets/{id}/top-up | Top up wallet
*WalletsApi* | [**wallets_id_transactions_get**](docs/WalletsApi.md#wallets_id_transactions_get) | **GET** /wallets/{id}/transactions | Get wallet transactions
*WalletsApi* | [**wallets_post**](docs/WalletsApi.md#wallets_post) | **POST** /wallets | Create a new wallet
*SecretsApi* | [**secrets_api_keys_get**](docs/SecretsApi.md#secrets_api_keys_get) | **GET** /secrets/api/keys | List API keys
*SecretsApi* | [**secrets_api_keys_id_delete**](docs/SecretsApi.md#secrets_api_keys_id_delete) | **DELETE** /secrets/api/keys/{id} | Delete an API key
*SecretsApi* | [**secrets_api_keys_post**](docs/SecretsApi.md#secrets_api_keys_post) | **POST** /secrets/api/keys | Create a new API key


## Documentation For Models

 - [DtoAddress](docs/DtoAddress.md)
 - [DtoAggregatedEntitlement](docs/DtoAggregatedEntitlement.md)
 - [DtoAggregatedFeature](docs/DtoAggregatedFeature.md)
 - [DtoAuthResponse](docs/DtoAuthResponse.md)
 - [DtoBillingPeriodInfo](docs/DtoBillingPeriodInfo.md)
 - [DtoBulkIngestEventRequest](docs/DtoBulkIngestEventRequest.md)
 - [DtoCreateAPIKeyRequest](docs/DtoCreateAPIKeyRequest.md)
 - [DtoCreateAPIKeyResponse](docs/DtoCreateAPIKeyResponse.md)
 - [DtoCreateCustomerRequest](docs/DtoCreateCustomerRequest.md)
 - [DtoCreateEntitlementRequest](docs/DtoCreateEntitlementRequest.md)
 - [DtoCreateEnvironmentRequest](docs/DtoCreateEnvironmentRequest.md)
 - [DtoCreateFeatureRequest](docs/DtoCreateFeatureRequest.md)
 - [DtoCreateIntegrationRequest](docs/DtoCreateIntegrationRequest.md)
 - [DtoCreateInvoiceLineItemRequest](docs/DtoCreateInvoiceLineItemRequest.md)
 - [DtoCreateInvoiceRequest](docs/DtoCreateInvoiceRequest.md)
 - [DtoCreateMeterRequest](docs/DtoCreateMeterRequest.md)
 - [DtoCreatePaymentRequest](docs/DtoCreatePaymentRequest.md)
 - [DtoCreatePlanEntitlementRequest](docs/DtoCreatePlanEntitlementRequest.md)
 - [DtoCreatePlanPriceRequest](docs/DtoCreatePlanPriceRequest.md)
 - [DtoCreatePlanRequest](docs/DtoCreatePlanRequest.md)
 - [DtoCreatePriceRequest](docs/DtoCreatePriceRequest.md)
 - [DtoCreatePriceTier](docs/DtoCreatePriceTier.md)
 - [DtoCreateSubscriptionRequest](docs/DtoCreateSubscriptionRequest.md)
 - [DtoCreateTaskRequest](docs/DtoCreateTaskRequest.md)
 - [DtoCreateTenantRequest](docs/DtoCreateTenantRequest.md)
 - [DtoCreateWalletRequest](docs/DtoCreateWalletRequest.md)
 - [DtoCustomerEntitlementsResponse](docs/DtoCustomerEntitlementsResponse.md)
 - [DtoCustomerInvoiceSummary](docs/DtoCustomerInvoiceSummary.md)
 - [DtoCustomerMultiCurrencyInvoiceSummary](docs/DtoCustomerMultiCurrencyInvoiceSummary.md)
 - [DtoCustomerResponse](docs/DtoCustomerResponse.md)
 - [DtoCustomerUsageSummaryResponse](docs/DtoCustomerUsageSummaryResponse.md)
 - [DtoEntitlementResponse](docs/DtoEntitlementResponse.md)
 - [DtoEntitlementSource](docs/DtoEntitlementSource.md)
 - [DtoEnvironmentResponse](docs/DtoEnvironmentResponse.md)
 - [DtoEvent](docs/DtoEvent.md)
 - [DtoFeatureResponse](docs/DtoFeatureResponse.md)
 - [DtoFeatureUsageSummary](docs/DtoFeatureUsageSummary.md)
 - [DtoGetEventsResponse](docs/DtoGetEventsResponse.md)
 - [DtoGetPreviewInvoiceRequest](docs/DtoGetPreviewInvoiceRequest.md)
 - [DtoGetUsageByMeterRequest](docs/DtoGetUsageByMeterRequest.md)
 - [DtoGetUsageBySubscriptionRequest](docs/DtoGetUsageBySubscriptionRequest.md)
 - [DtoGetUsageBySubscriptionResponse](docs/DtoGetUsageBySubscriptionResponse.md)
 - [DtoGetUsageRequest](docs/DtoGetUsageRequest.md)
 - [DtoGetUsageResponse](docs/DtoGetUsageResponse.md)
 - [DtoIngestEventRequest](docs/DtoIngestEventRequest.md)
 - [DtoInvoiceLineItemResponse](docs/DtoInvoiceLineItemResponse.md)
 - [DtoInvoiceResponse](docs/DtoInvoiceResponse.md)
 - [DtoLinkedIntegrationsResponse](docs/DtoLinkedIntegrationsResponse.md)
 - [DtoListCustomersResponse](docs/DtoListCustomersResponse.md)
 - [DtoListEntitlementsResponse](docs/DtoListEntitlementsResponse.md)
 - [DtoListEnvironmentsResponse](docs/DtoListEnvironmentsResponse.md)
 - [DtoListFeaturesResponse](docs/DtoListFeaturesResponse.md)
 - [DtoListInvoicesResponse](docs/DtoListInvoicesResponse.md)
 - [DtoListPaymentsResponse](docs/DtoListPaymentsResponse.md)
 - [DtoListPlansResponse](docs/DtoListPlansResponse.md)
 - [DtoListPricesResponse](docs/DtoListPricesResponse.md)
 - [DtoListSecretsResponse](docs/DtoListSecretsResponse.md)
 - [DtoListSubscriptionPausesResponse](docs/DtoListSubscriptionPausesResponse.md)
 - [DtoListSubscriptionsResponse](docs/DtoListSubscriptionsResponse.md)
 - [DtoListTasksResponse](docs/DtoListTasksResponse.md)
 - [DtoListWalletTransactionsResponse](docs/DtoListWalletTransactionsResponse.md)
 - [DtoLoginRequest](docs/DtoLoginRequest.md)
 - [DtoMeterResponse](docs/DtoMeterResponse.md)
 - [DtoPauseSubscriptionRequest](docs/DtoPauseSubscriptionRequest.md)
 - [DtoPaymentAttemptResponse](docs/DtoPaymentAttemptResponse.md)
 - [DtoPaymentResponse](docs/DtoPaymentResponse.md)
 - [DtoPlanResponse](docs/DtoPlanResponse.md)
 - [DtoPriceResponse](docs/DtoPriceResponse.md)
 - [DtoResumeSubscriptionRequest](docs/DtoResumeSubscriptionRequest.md)
 - [DtoSecretResponse](docs/DtoSecretResponse.md)
 - [DtoSignUpRequest](docs/DtoSignUpRequest.md)
 - [DtoSubscriptionPauseResponse](docs/DtoSubscriptionPauseResponse.md)
 - [DtoSubscriptionResponse](docs/DtoSubscriptionResponse.md)
 - [DtoSubscriptionUsageByMetersResponse](docs/DtoSubscriptionUsageByMetersResponse.md)
 - [DtoTaskResponse](docs/DtoTaskResponse.md)
 - [DtoTenantBillingDetails](docs/DtoTenantBillingDetails.md)
 - [DtoTenantBillingUsage](docs/DtoTenantBillingUsage.md)
 - [DtoTenantResponse](docs/DtoTenantResponse.md)
 - [DtoTopUpWalletRequest](docs/DtoTopUpWalletRequest.md)
 - [DtoUpdateCustomerRequest](docs/DtoUpdateCustomerRequest.md)
 - [DtoUpdateEntitlementRequest](docs/DtoUpdateEntitlementRequest.md)
 - [DtoUpdateEnvironmentRequest](docs/DtoUpdateEnvironmentRequest.md)
 - [DtoUpdateFeatureRequest](docs/DtoUpdateFeatureRequest.md)
 - [DtoUpdateMeterRequest](docs/DtoUpdateMeterRequest.md)
 - [DtoUpdatePaymentRequest](docs/DtoUpdatePaymentRequest.md)
 - [DtoUpdatePaymentStatusRequest](docs/DtoUpdatePaymentStatusRequest.md)
 - [DtoUpdatePlanEntitlementRequest](docs/DtoUpdatePlanEntitlementRequest.md)
 - [DtoUpdatePlanPriceRequest](docs/DtoUpdatePlanPriceRequest.md)
 - [DtoUpdatePlanRequest](docs/DtoUpdatePlanRequest.md)
 - [DtoUpdatePriceRequest](docs/DtoUpdatePriceRequest.md)
 - [DtoUpdateTaskStatusRequest](docs/DtoUpdateTaskStatusRequest.md)
 - [DtoUpdateTenantRequest](docs/DtoUpdateTenantRequest.md)
 - [DtoUpdateWalletRequest](docs/DtoUpdateWalletRequest.md)
 - [DtoUsageResult](docs/DtoUsageResult.md)
 - [DtoUserResponse](docs/DtoUserResponse.md)
 - [DtoWalletBalanceResponse](docs/DtoWalletBalanceResponse.md)
 - [DtoWalletResponse](docs/DtoWalletResponse.md)
 - [DtoWalletTransactionResponse](docs/DtoWalletTransactionResponse.md)
 - [ErrorsErrorDetail](docs/ErrorsErrorDetail.md)
 - [ErrorsErrorResponse](docs/ErrorsErrorResponse.md)
 - [MeterAggregation](docs/MeterAggregation.md)
 - [MeterFilter](docs/MeterFilter.md)
 - [PriceJSONBTransformQuantity](docs/PriceJSONBTransformQuantity.md)
 - [PricePrice](docs/PricePrice.md)
 - [PricePriceTier](docs/PricePriceTier.md)
 - [PriceTransformQuantity](docs/PriceTransformQuantity.md)
 - [SubscriptionSubscriptionLineItem](docs/SubscriptionSubscriptionLineItem.md)
 - [SubscriptionSubscriptionPause](docs/SubscriptionSubscriptionPause.md)
 - [TypesAggregationType](docs/TypesAggregationType.md)
 - [TypesAutoTopupTrigger](docs/TypesAutoTopupTrigger.md)
 - [TypesBillingCadence](docs/TypesBillingCadence.md)
 - [TypesBillingModel](docs/TypesBillingModel.md)
 - [TypesBillingPeriod](docs/TypesBillingPeriod.md)
 - [TypesBillingTier](docs/TypesBillingTier.md)
 - [TypesEntityType](docs/TypesEntityType.md)
 - [TypesFeatureType](docs/TypesFeatureType.md)
 - [TypesFileType](docs/TypesFileType.md)
 - [TypesInvoiceBillingReason](docs/TypesInvoiceBillingReason.md)
 - [TypesInvoiceCadence](docs/TypesInvoiceCadence.md)
 - [TypesInvoiceStatus](docs/TypesInvoiceStatus.md)
 - [TypesInvoiceType](docs/TypesInvoiceType.md)
 - [TypesPaginationResponse](docs/TypesPaginationResponse.md)
 - [TypesPauseMode](docs/TypesPauseMode.md)
 - [TypesPauseStatus](docs/TypesPauseStatus.md)
 - [TypesPaymentDestinationType](docs/TypesPaymentDestinationType.md)
 - [TypesPaymentMethodType](docs/TypesPaymentMethodType.md)
 - [TypesPaymentStatus](docs/TypesPaymentStatus.md)
 - [TypesPriceType](docs/TypesPriceType.md)
 - [TypesResetUsage](docs/TypesResetUsage.md)
 - [TypesResumeMode](docs/TypesResumeMode.md)
 - [TypesSecretProvider](docs/TypesSecretProvider.md)
 - [TypesSecretType](docs/TypesSecretType.md)
 - [TypesStatus](docs/TypesStatus.md)
 - [TypesSubscriptionStatus](docs/TypesSubscriptionStatus.md)
 - [TypesTaskStatus](docs/TypesTaskStatus.md)
 - [TypesTaskType](docs/TypesTaskType.md)
 - [TypesTransactionReason](docs/TypesTransactionReason.md)
 - [TypesTransactionStatus](docs/TypesTransactionStatus.md)
 - [TypesTransactionType](docs/TypesTransactionType.md)
 - [TypesWalletConfig](docs/TypesWalletConfig.md)
 - [TypesWalletConfigPriceType](docs/TypesWalletConfigPriceType.md)
 - [TypesWalletStatus](docs/TypesWalletStatus.md)
 - [TypesWalletTxReferenceType](docs/TypesWalletTxReferenceType.md)
 - [TypesWalletType](docs/TypesWalletType.md)
 - [TypesWindowSize](docs/TypesWindowSize.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header


## Author




